pub fn connected_components(
mask: &BinaryMask,
connectivity: Connectivity,
) -> VisionResult<ConnectedComponents>Expand description
Labels foreground components and computes bounding boxes and centroids.
pub fn connected_components(
mask: &BinaryMask,
connectivity: Connectivity,
) -> VisionResult<ConnectedComponents>Labels foreground components and computes bounding boxes and centroids.