pub fn crop<T: PixelComponent, const CHANNELS: usize>(
input: ImageView<'_, T, CHANNELS>,
region: ImageRegion,
) -> VisionResult<Image<T, CHANNELS>>Expand description
Copies a checked rectangular region into a packed image.
pub fn crop<T: PixelComponent, const CHANNELS: usize>(
input: ImageView<'_, T, CHANNELS>,
region: ImageRegion,
) -> VisionResult<Image<T, CHANNELS>>Copies a checked rectangular region into a packed image.