dense_flow_block_match

Function dense_flow_block_match 

pub fn dense_flow_block_match(
    previous: ImageView<'_, u8, 1>,
    next: ImageView<'_, u8, 1>,
    options: DenseFlowOptions,
) -> VisionResult<FlowField>
Computes a dense integer flow field with deterministic local block matching.

Pixels whose full block/search window leaves the image are marked with NaN.