pub fn depth_map_to_point_cloud(
depth: &DepthMap,
camera: &PinholeCamera,
options: DepthConversionOptions,
) -> VisionResult<PointCloud>Expand description
Unprojects a depth map with a calibrated camera into an XYZ point cloud.
pub fn depth_map_to_point_cloud(
depth: &DepthMap,
camera: &PinholeCamera,
options: DepthConversionOptions,
) -> VisionResult<PointCloud>Unprojects a depth map with a calibrated camera into an XYZ point cloud.