pub fn project_object_point(
pose: AbsolutePose,
camera: CameraMatrix3,
object: Vec3<f64>,
) -> VisionResult<Vec2<f64>>Expand description
Projects an object point with an absolute pose into pixel coordinates.
pub fn project_object_point(
pose: AbsolutePose,
camera: CameraMatrix3,
object: Vec3<f64>,
) -> VisionResult<Vec2<f64>>Projects an object point with an absolute pose into pixel coordinates.