pub fn swap_red_blue<T: PixelComponent>(
input: ImageView<'_, T, 3>,
) -> VisionResult<Image<T, 3>>Expand description
Swaps the red and blue channels of a three-channel image.
pub fn swap_red_blue<T: PixelComponent>(
input: ImageView<'_, T, 3>,
) -> VisionResult<Image<T, 3>>Swaps the red and blue channels of a three-channel image.