pub struct AdaptiveBackgroundModel { /* private fields */ }Expand description
Stateful single-Gaussian grayscale background model.
Implementations
Sourceimpl AdaptiveBackgroundModel
impl AdaptiveBackgroundModel
Sourcepub fn try_new(
frame: ImageView<'_, u8, 1>,
options: BackgroundModelOptions,
) -> VisionResult<Self>
pub fn try_new( frame: ImageView<'_, u8, 1>, options: BackgroundModelOptions, ) -> VisionResult<Self>
Initializes the model from its first frame.
Sourcepub fn apply(
&mut self,
frame: ImageView<'_, u8, 1>,
) -> VisionResult<BackgroundUpdate>
pub fn apply( &mut self, frame: ImageView<'_, u8, 1>, ) -> VisionResult<BackgroundUpdate>
Segments foreground and updates background statistics in one explicit step.
Sourcepub const fn frames_seen(&self) -> u64
pub const fn frames_seen(&self) -> u64
Returns the number of frames incorporated into the model.