pub struct DepthMap { /* private fields */ }Expand description
Metric or relative dense depth map. Non-positive and non-finite values are invalid.
Implementations
Sourceimpl DepthMap
impl DepthMap
Sourcepub fn try_new(
width: usize,
height: usize,
data: Vec<f32>,
) -> VisionResult<Self>
pub fn try_new( width: usize, height: usize, data: Vec<f32>, ) -> VisionResult<Self>
Wraps a depth image and marks its semantic metadata.
Sourcepub fn valid_mask(
&self,
min_depth: f32,
max_depth: f32,
) -> VisionResult<BinaryMask>
pub fn valid_mask( &self, min_depth: f32, max_depth: f32, ) -> VisionResult<BinaryMask>
Builds a validity mask for an inclusive depth range.