pub struct DescriptorBuffer { /* private fields */ }Expand description
Row-major descriptor matrix with a fixed width and explicit scalar kind.
Implementations
Sourceimpl DescriptorBuffer
impl DescriptorBuffer
Sourcepub fn try_binary(
rows: usize,
bytes_per_row: usize,
data: Vec<u8>,
) -> VisionResult<Self>
pub fn try_binary( rows: usize, bytes_per_row: usize, data: Vec<u8>, ) -> VisionResult<Self>
Creates a checked row-major binary descriptor matrix.
Sourcepub fn try_float32(
rows: usize,
values_per_row: usize,
data: Vec<f32>,
) -> VisionResult<Self>
pub fn try_float32( rows: usize, values_per_row: usize, data: Vec<f32>, ) -> VisionResult<Self>
Creates a checked row-major float32 descriptor matrix.
Sourcepub const fn kind(&self) -> DescriptorKind
pub const fn kind(&self) -> DescriptorKind
Returns the descriptor scalar representation.
Sourcepub fn binary_row(&self, index: usize) -> Option<&[u8]>
pub fn binary_row(&self, index: usize) -> Option<&[u8]>
Returns one binary descriptor, or None for a wrong kind or row index.
Sourcepub fn float32_row(&self, index: usize) -> Option<&[f32]>
pub fn float32_row(&self, index: usize) -> Option<&[f32]>
Returns one float descriptor, or None for a wrong kind or row index.
Sourcepub fn binary_data(&self) -> Option<&[u8]>
pub fn binary_data(&self) -> Option<&[u8]>
Returns packed binary storage when the descriptor kind is binary.
Sourcepub fn float32_data(&self) -> Option<&[f32]>
pub fn float32_data(&self) -> Option<&[f32]>
Returns packed float storage when the descriptor kind is float32.