GeometricEstimate

Struct GeometricEstimate 

pub struct GeometricEstimate<Model> { /* private fields */ }
A geometric model paired with one inlier decision and residual per input row.

Implementations

Source

impl<Model> GeometricEstimate<Model>

pub fn try_new( model: Model, correspondence_count: usize, inliers: Vec<bool>, residuals: Vec<f64>, ) -> VisionResult<Self>

Creates a result whose inlier and residual arrays match the input count.

pub const fn model(&self) -> &Model

Returns the estimated model.

pub fn inliers(&self) -> &[bool]

Returns one inlier decision per input correspondence.

pub fn residuals(&self) -> &[f64]

Returns one non-negative geometric residual per input correspondence.

pub fn inlier_count(&self) -> usize

Returns the number of accepted correspondences.