pub fn match_descriptors(
query: &DescriptorBuffer,
train: &DescriptorBuffer,
options: MatchOptions,
) -> VisionResult<Vec<FeatureMatch>>Expand description
Matches each query descriptor to its nearest train descriptor.
Binary rows use Hamming distance and float rows use Euclidean L2 distance. Equal distances are resolved by the lowest row index. Returned matches remain in ascending query-row order.