pub fn sobel_abs_3x3_u8(
input: ImageView<'_, u8, 1>,
dx: usize,
dy: usize,
border: BorderMode<u8, 1>,
) -> VisionResult<Image<u8, 1>>Expand description
Computes an exact absolute first-order 3x3 Sobel response as saturated u8.
This fuses signed derivative calculation, absolute value, and saturation, avoiding the signed intermediate image required by a two-stage pipeline.