pub struct BinaryMask { /* private fields */ }Expand description
Validated binary mask (0 background, 1 foreground).
Implementations
Sourceimpl BinaryMask
impl BinaryMask
Sourcepub fn try_new(width: usize, height: usize, data: Vec<u8>) -> VisionResult<Self>
pub fn try_new(width: usize, height: usize, data: Vec<u8>) -> VisionResult<Self>
Creates a mask and rejects values other than zero and one.
Sourcepub fn from_threshold(
input: ImageView<'_, f32, 1>,
threshold: f32,
) -> VisionResult<Self>
pub fn from_threshold( input: ImageView<'_, f32, 1>, threshold: f32, ) -> VisionResult<Self>
Thresholds a float score image into a binary mask.
Sourcepub fn into_image(self) -> Image<u8, 1>
pub fn into_image(self) -> Image<u8, 1>
Consumes the wrapper and returns its image.